==> dvdisaster-0.72.3.tar.bz2: dvdisaster-0.72.3/documentation/include/toc.php <==

<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2010 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

section("news");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

subsection("news2008");
  de("2008");
  en("2008");
  ru("2008");

subsection("news2007");
  de("2007");
  en("2007");
  ru("2007");

# Overview

section("index");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  de("Das große Bild");
  en("The big picture");
  ru("Общая картина");

subsubsection("howtos61");
  de("Fehlerkorrektur");
  en("error correction");
  ru("исправление ошибок");

subsubsection("howtos62");
  de("richtige Anwendung");
  en("correct usage");
  ru("правильное использование");

subsubsection("howtos63");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("неправильное использование");

subsection("howtos10");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителях");

subsubsection("howtos11");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные настройки");

subsubsection("howtos12");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("Выполнение проверки");

subsubsection("howtos13");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("Объяснение результатов");

subsubsection("howtos14");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные настройки");

subsection("howtos20");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Размещение данных для исправления ошибок в отдельном файле");

subsubsection("howtos21");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos22");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Основные настройки для чтения");

subsubsection("howtos23");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Создание файла для исправления ошибок");

subsubsection("howtos24");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Архивация файлов для исправления ошибок");

subsubsection("howtos25");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos30");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Размещение данных для исправления ошибок на носителе");

subsubsection("howtos31");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos32");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos33");
  de("Datenträger erzeugen");
  en("Creating the medium");
  ru("Создание носителя");

subsubsection("howtos34");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos40");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsubsection("howtos41");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos42");
  de("Abbild rekonstruieren");
  en("Recovering the image");
  ru("Восстановление образа");

subsubsection("howtos43");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos50");
  de("Informationen über Abbilder und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsubsection("howtos51");
  de("Informationen anzeigen");
  en("Show information");
  ru("Показать информацию");

subsubsection("howtos52");
  de("Ausgaben für Fehlerkorrektur-Dateien");
  en("Results for error correction files");
  ru("Результаты для файлов с данными для исправления ошибок");

subsubsection("howtos53");
  de("Ausgaben für erweiterte Abbilder");
  en("Results für augmented images");
  ru("Результаты для дополненных образов");

subsubsection("howtos59");
  de("Beispiele");
  en("Examples");
  ru("Примеры");

subsection("howtos90");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");
  ru("Проверка совместимости образов");

subsubsection("howtos91");
  de("bei Fehlerkorrektur-Dateien");
  en("with error correction files");
  ru("с файлами для исправления ошибок");

subsubsection("howtos92");
  de("beim Ablegen von Fehlerkorrektur-Daten auf dem Datenträger");
  en("when augmenting images with error correction data");
  ru("при дополнении образов данными для исправления ошибок");

subsection("howtosa0");
  de("Bedienelemente");
  en("Dialogs and buttons");
  ru("Диалоги и кнопки");

subsubsection("howtosa1");
  de("Laufwerk auswählen");
  en("Drive selection");
  ru("Выбор привода");

subsubsection("howtosa2");
  de("Abbild-Datei auswählen");
  en("Image file selection");
  ru("Выбор файла образа");

subsubsection("howtosa3");
  de("Fehlerkorrektur-Datei auswählen");
  en("Error correction file selection");
  ru("Выбор файла для исправления ошибок");

subsubsection("howtosa4");
  de("Aktionen beginnen");
  en("Starting actions");
  ru("Начало действий");
# Download

section("download");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download20");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  de("Installation");
  en("Installation");
  ru("Установка");

#subsection("download40");
#  de("Alpha-/Entwicklerversionen");
#  en("Alpha (unstable) versions");
#  ru("Альфа (нестабильные) версии");

# Questions and Answers

section("qa");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

# Feedback

section("feedback");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

if(strcmp($mode, "local"))
{
  # Imprint

section("imprint");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

   # Privacy notice

section("privacy");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Политика конфиденциальности");
}
?>

==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/include/toc.php <==
<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2012 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

global $have_experimental;

section("news");
  cs("Novinky");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

subsection("news2009");
  cs("2009");
  de("2009");
  en("2009");
  ru("2009");

subsection("news2008");
  cs("2008");
  de("2008");
  en("2008");
  ru("2008");

subsection("news2007");
  cs("2007");
  de("2007");
  en("2007");
  ru("2007");

# Overview

section("index");
  cs("Přehled");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  cs("Příklady opravy chyb");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  cs("dvdisaster jako doplněk kontrol kvality");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  cs("Výhody a nevýhody programu dvdisaster");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  cs("Běžné použití");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  cs("Celkový přehled");
  de("Das große Bild");
  en("The big picture");
  ru("Общая картина");

subsubsection("howtos61");
  cs("oprava chyb");
  de("Fehlerkorrektur");
  en("error correction");
  ru("исправление ошибок");

subsubsection("howtos62");
  cs("správné použití");
  de("richtige Anwendung");
  en("correct usage");
  ru("правильное использование");

subsubsection("howtos63");
  cs("chybné použití");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("неправильное использование");

subsection("howtos10");
  cs("Kontrola poškození disků");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителях");

subsubsection("howtos11");
  cs("Základní nastavení");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные настройки");

subsubsection("howtos12");
  cs("Postup");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("Выполнение проверки");

subsubsection("howtos13");
  cs("Interpretace výsledků");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("Объяснение результатов");

subsubsection("howtos14");
  cs("Pokročilá nastavení");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные настройки");

subsection("howtos20");
  cs("Vytvoření samostatného souboru pro opravu chyb");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Размещение данных для исправления ошибок в отдельном файле");

subsubsection("howtos21");
  cs("Pomoc s&nbsp;rozhodováním");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos22");
  cs("Základní nastavení");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Основные настройки для чтения");

subsubsection("howtos23");
  cs("Vytvoření souboru pro opravu chyb");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Создание файла для исправления ошибок");

subsubsection("howtos24");
  cs("Uchovávání souborů pro opravu chyb");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Архивация файлов для исправления ошибок");

subsubsection("howtos25");
  cs("Pokročilá nastavení");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos30");
  cs("Rozšíření bitové kopie o&nbsp;data pro opravu chyb");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Размещение данных для исправления ошибок на носителе");

subsubsection("howtos31");
  cs("Pomoc s&nbsp;rozhodováním");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos32");
  cs("Základní nastavení");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos33");
  cs("Vytvoření disku");
  de("Datenträger erzeugen");
  en("Creating the medium");
  ru("Создание носителя");

subsubsection("howtos34");
  cs("Pokročilá nastavení");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos40");
  cs("Oprava bitových kopií");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsubsection("howtos41");
  cs("Základní nastavení");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos42");
  cs("Oprava bitové kopie");
  de("Abbild rekonstruieren");
  en("Recovering the image");
  ru("Восстановление образа");

subsubsection("howtos43");
  cs("Pokročilá nastavení");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos50");
  cs("Zjištění informací o&nbsp;bitových kopiích a datech pro opravu chyb");
  de("Informationen über Abbilder und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsubsection("howtos51");
  cs("Zobrazení informací");
  de("Informationen anzeigen");
  en("Show information");
  ru("Показать информацию");

subsubsection("howtos52");
  cs("Výsledky pro soubory pro opravu chyb");
  de("Ausgaben für Fehlerkorrektur-Dateien");
  en("Results for error correction files");
  ru("Результаты для файлов с данными для исправления ошибок");

subsubsection("howtos53");
  cs("Výsledky pro rozšířené bitové kopie");
  de("Ausgaben für erweiterte Abbilder");
  en("Results for augmented images");
  ru("Результаты для дополненных образов");

subsubsection("howtos59");
  cs("Příklady");
  de("Beispiele");
  en("Examples");
  ru("Примеры");

subsection("howtos90");
  cs("Testování kompatibility bitové kopie");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");
  ru("Проверка совместимости образов");

subsubsection("howtos91");
  cs("se&nbsp;soubory pro opravu chyb");
  de("bei Fehlerkorrektur-Dateien");
  en("with error correction files");
  ru("с файлами для исправления ошибок");

subsubsection("howtos92");
  cs("při rozšiřování bitové kopie o&nbsp;data pro opravu chyb");
  de("beim Ablegen von Fehlerkorrektur-Daten auf dem Datenträger");
  en("when augmenting images with error correction data");
  ru("при дополнении образов данными для исправления ошибок");

subsection("howtosa0");
  cs("Dialogy a tlačítka");
  de("Bedienelemente");
  en("Dialogs and buttons");
  ru("Диалоги и кнопки");

subsubsection("howtosa1");
  cs("Výběr mechaniky");
  de("Laufwerk auswählen");
  en("Drive selection");
  ru("Выбор привода");

subsubsection("howtosa2");
  cs("Výběr bitové kopie");
  de("Abbild-Datei auswählen");
  en("Image file selection");
  ru("Выбор файла образа");

subsubsection("howtosa3");
  cs("Výběr souboru pro opravu chyb");
  de("Fehlerkorrektur-Datei auswählen");
  en("Error correction file selection");
  ru("Выбор файла для исправления ошибок");

subsubsection("howtosa4");
  cs("Spuštění akcí");
  de("Aktionen beginnen");
  en("Starting actions");
  ru("Начало действий");

# Download

section("download");
  cs("Ke&nbsp;stažení");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  cs("Systémové požadavky");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download60");
  cs("(Žádné) podmínky pro stažení");
  de("(Keine) Bedingungen zum Herunterladen");
  en("(No) download terms");
  ru("(No) download terms");

subsection("download20");
  cs("Digitální podpis");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  cs("Instalace");
  de("Installation");
  en("Installation");
  ru("Установка");

if(!strcmp($have_experimental, "yes"))
{
subsection("download40");
  cs("Alpha (vývojové) verze");
  de("Alpha-/Entwicklerversionen");
  en("Alpha (unstable) versions");
  ru("Альфа (нестабильные) версии");
}

subsection("download50");
  cs("Ostatní zdroje informací");
  de("Zusätzliche Papiere");
  en("Additional resources");
  ru("Additional resources");

# Questions and Answers

section("qa");
  cs("Otázky a odpovědi");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  cs("Technické otázky");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  cs("Chybová hlášení");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

subsection("qa30");
  cs("Technické informace");
  de("Hintergrundinformationen");
  en("Background information");
  ru("Background information");

subsubsection("qa31");
  cs("Vlastnosti opravy chyb");
  de("Eigenschaften der Fehlerkorrektur");
  en("Error correction properties");
  ru("Error correction properties");

subsubsection("qa32");
  cs("Oprava dat na&nbsp;úrovni bitové kopie");
  de("Datenrekonstruktion auf Abbild-Ebene");
  en("Image level data recovery");
  ru("Image level data recovery");

subsubsection("qa33");
  cs("RS01, RS02 a RS03");
  de("RS01, RS02 und RS03");
  en("RS01, RS02 and RS03");
  ru("RS01, RS02 and RS03");

subsubsection("qa34");
  cs("Lineární strategie čtení");
  de("Lineares Lese-Verfahren");
  en("Linear reading strategy");
  ru("Linear reading strategy");

subsubsection("qa35");
  cs("Adaptivní strategie čtení");
  de("Angepaßtes Lese-Verfahren");
  en("Adaptive reading strategy");
  ru("Adaptive reading strategy");

subsubsection("qa36");
  cs("Poznámky k&nbsp;chybám čtení");
  de("Bemerkungen zu Lesefehlern");
  en("Remarks on read errors");
  ru("Remarks on read errors");

subsubsection("qa37");
  cs("Tipy pro uchovávání souborů pro opravu chyb");
  de("Fehlerkorrektur-Datei aufbewahren");
  en("Hints for storing the error correction files");
  ru("Hints for storing the error correction files");

# Feedback

section("feedback");
  cs("Hlášení chyb");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

if(strcmp($mode, "local"))
{
  # Imprint

section("imprint");
  cs("Kontakt");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

   # Privacy notice

section("privacy");
  cs("Zásady ochrany osobních údajů");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Политика конфиденциальности");
}
?>
